@@ -37,6 +37,7 @@ try:
     from urllib2 import HTTPError, URLError
     from httplib import BadStatusLine
 
+    from prettytable import PrettyTable
     from common import __version__, config_file, config_fields
     from common import grammar, precached_verbs
     from marvin.cloudstackConnection import cloudConnection
@@ -65,7 +66,7 @@ logger = logging.getLogger(__name__)
 completions = cloudstackAPI.__all__
 
 
-class CloudStackShell(cmd.Cmd, object):
+class CloudMonkeyShell(cmd.Cmd, object):
     intro = ("☁ Apache CloudStack 🐵 cloudmonkey " + __version__ +
              ". Type help or ? to list commands.\n")
     ruler = "="
@@ -137,7 +138,7 @@ class CloudStackShell(cmd.Cmd, object):
         print self.intro
         while True:
             try:
-                super(CloudStackShell, self).cmdloop(intro = "")
+                super(CloudMonkeyShell, self).cmdloop(intro="")
                 self.postloop()
             except KeyboardInterrupt:
                 print("^C")
@@ -173,29 +174,58 @@ class CloudStackShell(cmd.Cmd, object):
         except Exception, e:
             print colored.red("Error: "), e
 
-    def print_result(self, result):
+    def print_result(self, result, result_filter=None):
         if result is None or len(result) == 0:
             return
 
-        def print_result_as_dict(result):
+        def printer_helper(printer, toprow):
+            if printer:
+                print printer
+            return PrettyTable(toprow)
+
+        def print_result_tabular(result, result_filter=None):
+            toprow = None
+            printer = None
+            for node in result:
+                if toprow != node.keys():
+                    if result_filter is not None and len(result_filter) != 0:
+                        commonkeys = filter(lambda x: x in node.keys(),
+                                            result_filter)
+                        if commonkeys != toprow:
+                            toprow = commonkeys
+                            printer = printer_helper(printer, toprow)
+                    else:
+                        toprow = node.keys()
+                        printer = printer_helper(printer, toprow)
+                row = map(lambda x: node[x], toprow)
+                if printer and row:
+                    printer.add_row(row)
+            if printer:
+                print printer
+
+        def print_result_as_dict(result, result_filter=None):
             for key in result.keys():
                 if not (isinstance(result[key], list) or
                         isinstance(result[key], dict)):
                     self.print_shell("%s = %s" % (key, result[key]))
                 else:
-                    self.print_shell(key + ":\n" + len(key) * "=")
-                    self.print_result(result[key])
+                    self.print_shell(key + ":\n" + len(key) * self.ruler)
+                    self.print_result(result[key], result_filter)
 
-        def print_result_as_list(result):
+        def print_result_as_list(result, result_filter=None):
             for node in result:
+                # Tabular print if it's a list of dict and tabularize is true
+                if isinstance(node, dict) and self.tabularize == 'true':
+                    print_result_tabular(result, result_filter)
+                    break
                 self.print_result(node)
                 if len(result) > 1:
                     self.print_shell(self.ruler * 80)
 
         if isinstance(result, dict):
-            print_result_as_dict(result)
+            print_result_as_dict(result, result_filter)
         elif isinstance(result, list):
-            print_result_as_list(result)
+            print_result_as_list(result, result_filter)
         elif isinstance(result, str):
             print result
         elif not (str(result) is None):
@@ -281,6 +311,11 @@ class CloudStackShell(cmd.Cmd, object):
         args_dict = dict(map(lambda x: [x.partition("=")[0],
                                         x.partition("=")[2]],
                              args[1:])[x] for x in range(len(args) - 1))
+        field_filter = None
+        if 'filter' in args_dict:
+            field_filter = filter(lambda x: x is not '',
+                                  map(lambda x: x.strip(),
+                                      args_dict.pop('filter').split(',')))
 
         api_cmd_str = "%sCmd" % api_name
         api_mod = self.get_api_module(api_name, [api_cmd_str])
@@ -312,7 +347,9 @@ class CloudStackShell(cmd.Cmd, object):
         if result is None:
             return
         try:
-            self.print_result(result.values())
+            # Response is in the key "apiname+response" (lowercase)
+            self.print_result(result[api_name.lower() + 'response'],
+                              field_filter)
             print
         except Exception as e:
             self.print_shell("🙈  Error on parsing and printing", e)
@@ -366,6 +403,7 @@ class CloudStackShell(cmd.Cmd, object):
                                   self.cache_verbs[verb][subject][1])
             search_string = text
 
+        autocompletions.append("filter=")
         return [s for s in autocompletions if s.startswith(search_string)]
 
     def do_api(self, args):
@@ -387,7 +425,7 @@ class CloudStackShell(cmd.Cmd, object):
 
     def do_set(self, args):
         """
-        Set config for CloudStack CLI. Available options are:
+        Set config for cloudmonkey. For example, options can be:
         host, port, apikey, secretkey, log_file, history_file
         You may also edit your ~/.cloudmonkey_config instead of using set.
 
@@ -459,13 +497,13 @@ class CloudStackShell(cmd.Cmd, object):
 
     def do_exit(self, args):
         """
-        Quit Apache CloudStack CLI
+        Quit CloudMonkey CLI
         """
         return self.do_quit(args)
 
     def do_quit(self, args):
         """
-        Quit Apache CloudStack CLI
+        Quit CloudMonkey CLI
         """
         self.print_shell("Bye!")
         return self.do_EOF(args)
@@ -479,7 +517,7 @@ class CloudStackShell(cmd.Cmd, object):
 
 def main():
     # Create handlers on the fly using closures
-    self = CloudStackShell
+    self = CloudMonkeyShell
     global grammar
     for rule in grammar:
         def add_grammar(rule):
@@ -495,7 +533,6 @@ def main():
                 try:
                     args_partition = args.partition(" ")
                     res = self.cache_verbs[rule][args_partition[0]]
-
                 except KeyError, e:
                     self.print_shell("Error: invalid %s api arg" % rule, e)
                     return
@@ -510,7 +547,7 @@ def main():
         grammar_handler.__name__ = 'do_' + rule
         setattr(self, grammar_handler.__name__, grammar_handler)
 
-    shell = CloudStackShell()
+    shell = CloudMonkeyShell()
     if len(sys.argv) > 1:
         shell.onecmd(' '.join(sys.argv[1:]))
     else:
