@@ -151,6 +151,8 @@ from listAlerts import listAlertsResponse
 from listCapacity import listCapacityResponse
 from addSwift import addSwiftResponse
 from listSwifts import listSwiftsResponse
+from addS3 import addS3Response
+from listS3s import listS3sResponse
 from addHost import addHostResponse
 from addCluster import addClusterResponse
 from deleteCluster import deleteClusterResponse
@@ -1058,6 +1060,16 @@ class CloudStackAPIClient:
         response = self.connection.make_request(command, response)
         return response
 
+    def addS3(self,command):
+        response = addS3Response()
+        response = self.connection.make_request(command, response)
+        return response
+
+    def listS3s(self,command):
+        response = listS3sResponse()
+        response = self.connection.make_request(command, response)
+        return response
+
     def addHost(self,command):
         response = addHostResponse()
         response = self.connection.make_request(command, response)
