@@ -22,6 +22,4 @@ class createSSHKeyPairResponse (baseResponse):
         self.fingerprint = None
         """Name of the keypair"""
         self.name = None
-        """Private key"""
-        self.privatekey = None
 
