@@ -33,6 +33,4 @@ class listSSHKeyPairsResponse (baseResponse):
         self.fingerprint = None
         """Name of the keypair"""
         self.name = None
-        """Private key"""
-        self.privatekey = None
 
